@@ -136,7 +136,7 @@ void PsychComposeCompressedStereoBuffer(PsychWindowRecordType *windowRecord);
 void		PsychCleanupTextRenderer(PsychWindowRecordType* windowRecord);
 psych_bool	PsychLoadTextRendererPlugin(PsychWindowRecordType* windowRecord);
 void		PsychDrawCharText(PsychWindowRecordType* winRec, const char* textString, double* xp, double* yp, unsigned int yPositionIsBaseline, PsychColorType *textColor, PsychColorType *backgroundColor, PsychRectType* boundingbox);
-PsychError	PsychDrawUnicodeText(PsychWindowRecordType* winRec, PsychRectType* boundingbox, unsigned int stringLengthChars, double* textUniDoubleString, double* xp, double* yp, unsigned int yPositionIsBaseline, PsychColorType *textColor, PsychColorType *backgroundColor, int swapTextDirection);
+PsychError	PsychDrawUnicodeText(PsychWindowRecordType* winRec, PsychRectType* boundingbox, unsigned int stringLengthChars, double* textUniDoubleString, double* xp, double* yp, double* theight, unsigned int yPositionIsBaseline, PsychColorType *textColor, PsychColorType *backgroundColor, int swapTextDirection);
 PsychError	PsychOSDrawUnicodeText(PsychWindowRecordType* winRec, PsychRectType* boundingbox, unsigned int stringLengthChars, double* textUniDoubleString, double* xp, double* yp, unsigned int yPositionIsBaseline, PsychColorType *textColor, PsychColorType *backgroundColor);
 psych_bool	PsychAllocInTextAsUnicode(int position, PsychArgRequirementType isRequired, int *textLength, double **unicodeText);
 psych_bool	PsychSetUnicodeTextConversionLocale(char* mnewlocale);
@@ -180,6 +180,7 @@ PsychError 	SCREENTextSize(void);
 PsychError 	SCREENTextStyle(void);					
 PsychError 	SCREENTextFont(void);					
 PsychError      SCREENTextBounds(void);					
+PsychError      SCREENTextTransform(void);
 PsychError      SCREENDrawText(void);					
 PsychError      SCREENTextColor(void);					
 PsychError      SCREENPreference(void);					
